@@ -4,6 +4,7 @@ import numpy as np
 import pandas as pd
 from Functions import GUI as G
 from Functions import Modelisation as mod
+import os
 import argparse
 from pathlib import Path
 
@@ -16,6 +17,7 @@ def parse():
     parser.add_argument('--inp', help='data location', dest='in_cfg' , default=None)
     parser.add_argument('--format', help='format of the plot', default='.jpg', dest='form')
     parser.add_argument('--dir', help='create input and output folder', action='store_true')
+    parser.add_argument('--hello',action='store_true',help='Launch thre web interface')
     return parser.parse_args()
 
 
@@ -26,6 +28,9 @@ if __name__ == "__main__":
         print('Done')
         sys.exit(0)
 
+    if args.hello:
+        os.system("streamlit run hello.py")
+    
     if args.out_cfg!=None and args.in_cfg!=None:
         mod.Data_read(args.in_cfg,args.out_cfg,args.form)
         print('Done')
